@@ -1,7 +1,8 @@
-// $Id: AppData.h,v 1.129 1999/09/27 08:05:44 andreas Exp $ -*- C++ -*-
+// $Id: AppData.h,v 1.130 2000/02/11 23:00:30 andreas Exp $ -*- C++ -*-
 // DDD application data
 
 // Copyright (C) 1996-1998 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 2000 Universitaet Passau, Germany.
 // Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
@@ -77,6 +78,8 @@
 #define XtNsourceInitCommands    "sourceInitCommands"
 #define XtCSourceInitCommands    "SourceInitCommands"
 #define XtCSettings              "Settings"
+#define XtNinitSymbols           "initSymbols"
+#define XtCInitSymbols           "InitSymbols"
 #define XtNvslPath               "vslPath"
 #define XtCVSLPath               "VSLPath"
 #define XtNvslLibrary            "vslLibrary"
@@ -420,6 +423,7 @@ struct AppData {
     String    perl_settings;
     String    restart_commands;
     Boolean   source_init_commands;
+    String    init_symbols;
     String    vsl_path;
     String    vsl_library;
     String    vsl_defs;
