@@ -1,8 +1,8 @@
-// $Id: Box.h,v 1.15 1998/03/25 12:42:22 zeller Exp $
-// Klasse Box (Deklaration)
+// $Id: Box.h,v 1.18 1999/08/19 11:27:06 andreas Exp $
+// Box class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_Box_h
 #define _DDD_Box_h
@@ -50,6 +50,7 @@
 #include "BoxWeight.h"
 #include "BoxRegion.h"
 #include "BoxExtend.h"
+#include "PrintGC.h"
 #include "Widget.h"
 #include "bool.h"
 #include "UniqueId.h"
@@ -58,46 +59,6 @@
 
 class TagBox;
 
-// Printing environment
-struct BoxPrintGC {
-    DECLARE_TYPE_INFO
-
-    virtual bool isFig() const        { return false; }
-    virtual bool isPostScript() const { return false; }
-};
-
-struct BoxFigGC: public BoxPrintGC {
-    DECLARE_TYPE_INFO
-
-    virtual bool isFig() const        { return true; }
-
-    BoxFigGC() {}
-};
-
-struct BoxPostScriptGC: public BoxPrintGC {
-    DECLARE_TYPE_INFO
-    enum Orientation { PORTRAIT, LANDSCAPE };
-
-    virtual bool isPostScript() const { return true; }
-
-    int hsize;   // Maximum size of graph in 1/72" (Portrait)
-    int vsize;
-
-    int hoffset; // Lower left corner of graph on page in 1/72" (Portrait)
-    int voffset;
-
-    Orientation orientation;	// Whether graph should be rotated
-
-    // Default: let params fit to an A4-sized page
-    BoxPostScriptGC():
-        hsize(510), vsize(794), 
-	hoffset(42), voffset(35), 
-	orientation(PORTRAIT)
-    {}
-};
-
-
-
 // Box class
 class Box {
 public:
@@ -113,7 +74,7 @@ private:
 
     static void epsHeader (ostream& os, 
 			   const BoxRegion& region, 
-			   const BoxPostScriptGC& gc);
+			   const PostScriptPrintGC& gc);
 
     Box& operator = (const Box&) { assert(0); return *this; }
 
@@ -200,7 +161,7 @@ public:
     // Return free space in lower right corner
     virtual BoxSize corner() const
     {
-	// Default: Platz der Breite 0 rechts von Box
+	// Default: space of zero width on the right of box
 	return BoxSize(0, _size[Y]);
     }
 
@@ -221,21 +182,21 @@ public:
     // Print box; Header/trailer must be pre-/postfixed
     virtual void _print(ostream& os, 
 			const BoxRegion& region, 
-			const BoxPrintGC& gc) const = 0;
+			const PrintGC& gc) const = 0;
 
     // Print Header/trailer
     static void _printHeader(ostream& os, 
 			     const BoxRegion& region, 
-			     const BoxPrintGC& gc);
+			     const PrintGC& gc);
     static void _printTrailer(ostream& os, 
 			      const BoxRegion& region, 
-			      const BoxPrintGC& gc);
+			      const PrintGC& gc);
 
     // Custom function: print box with header and trailer
     void print(ostream& os = cout,
 	       BoxRegion region = 
 	           BoxRegion(BoxPoint(0,0), BoxSize(0,0)),
-	       const BoxPrintGC& gc = BoxPostScriptGC()) const
+	       const PrintGC& gc = PostScriptPrintGC()) const
     {
 	region.space(X) = max(region.space(X), size(X));
 	region.space(Y) = max(region.space(Y), size(Y));
@@ -262,7 +223,7 @@ public:
     BoxRegion region(BoxPoint p = BoxPoint(-1,-1)) const;   // current region
     Data *data(BoxPoint p = BoxPoint(-1,-1)) const;         // current data
     string name(BoxPoint p = BoxPoint(-1,-1)) const;        // current name
-    bool selected(BoxPoint p = BoxPoint(-1,-1)) const;   // Flag: selected?
+    bool selected(BoxPoint p = BoxPoint(-1,-1)) const;      // Flag: selected?
     string info(BoxPoint p = BoxPoint(-1,-1)) const;        // Debugging info
 
     // Return the box that is to be matched
