@@ -1,4 +1,4 @@
-// $Id: BreakPoint.h,v 1.33.4.1 1998/12/04 10:39:03 zeller Exp $
+// $Id: BreakPoint.h,v 1.37 2000/01/03 12:12:09 andreas Exp $
 // Breakpoint handler
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_BreakPoint_h
 #define _DDD_BreakPoint_h
@@ -48,7 +48,9 @@
 // Breakpoint type
 enum BPType {
     BREAKPOINT,			// Breakpoint
-    WATCHPOINT			// Watchpoint
+    WATCHPOINT,			// Watchpoint
+    TRACEPOINT,			// Tracepoint (as in GDB)
+    ACTIONPOINT 		// Actionpoint (`when' in DBX, action in Perl)
 };
 
 // What to do when breakpoint is reached
@@ -149,6 +151,7 @@ public:
 
     // Breakpoint type.
     BPType type() const { return mytype; }
+    string title() const;
 
     // What to do when breakpoint is reached.
     BPDispo dispo() const { return mydispo; }
