@@ -1,4 +1,4 @@
-// $Id: CallNode.h,v 1.13 1999/08/19 11:27:10 andreas Exp $
+// $Id: CallNode.h,v 1.14 2000/02/16 11:32:29 andreas Exp $
 // Function call VSL nodes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -98,7 +98,8 @@ public:
     // Destructor (includes arg)
     ~CallNode()
     {
-	if (_arg) delete _arg;
+	if (_arg != 0)
+	    delete _arg;
     }
 
     const Box *_eval(ListBox *arglist) const;
