@@ -1,8 +1,8 @@
-// $Id: DiagBox.h,v 1.9 1998/03/25 12:42:52 zeller Exp $
-// Klasse DiagBox (Deklaration)
+// $Id: DiagBox.h,v 1.12 1999/08/19 11:27:20 andreas Exp $
+// Diagnostic boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_DiagBox_h
 #define _DDD_DiagBox_h
@@ -62,7 +62,7 @@ public:
 
     virtual void _print(ostream&, 
 			const BoxRegion&, 
-			const BoxPrintGC&) const
+			const PrintGC&) const
     {
 	// do nothing
     }
