@@ -1,4 +1,4 @@
-// $Id: DispNode.h,v 1.41 1998/11/17 10:51:16 zeller Exp $
+// $Id: DispNode.h,v 1.43 1999/08/19 11:27:22 andreas Exp $
 // Store information about a single display espression
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_DispNode_h
 #define _DDD_DispNode_h
@@ -225,7 +225,8 @@ public:
 
 inline bool is_cluster(DispNode *dn)
 {
-    return dn->is_user_command() && dn->user_command() == CLUSTER_COMMAND;
+    return dn->is_user_command() && 
+	dn->user_command().contains(CLUSTER_COMMAND, 0);
 }
 
 #endif // _DDD_DispNode_h
