@@ -1,9 +1,9 @@
-/* $Id: DocSpace.c,v 1.7 1998/03/25 12:43:01 zeller Exp $ */
+/* $Id: DocSpace.c,v 1.8 1999/08/19 11:27:25 andreas Exp $ */
 /* DocSpace-Widget (Implementation) */
 
 /*
     Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-    Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+    Written by Andreas Zeller <zeller@gnu.org>.
 
     This file is part of DDD.
 
@@ -24,12 +24,12 @@
 
     DDD is the data display debugger.
     For details, see the DDD World-Wide-Web page, 
-    `http://www.cs.tu-bs.de/softech/ddd/',
-    or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+    `http://www.gnu.org/software/ddd/',
+    or send a mail to the DDD developers <ddd@gnu.org>.
 */
 
 char DocSpace_rcsid[] = 
-    "$Id: DocSpace.c,v 1.7 1998/03/25 12:43:01 zeller Exp $";
+    "$Id: DocSpace.c,v 1.8 1999/08/19 11:27:25 andreas Exp $";
 
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
