@@ -1,8 +1,8 @@
-// $Id: DummyBox.h,v 1.8 1998/03/25 12:43:03 zeller Exp $ 
-// Deklaration Klasse DummyBox
+// $Id: DummyBox.h,v 1.10 1999/08/19 11:27:26 andreas Exp $ 
+// `Dummy' boxes (for pattern matching)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_DummyBox_h
 #define _DDD_DummyBox_h
@@ -34,9 +34,10 @@
 #endif
 
 
-// Eine DummyBox wird -- fast ausschliesslich -- zum Pattern-Matching
-// verwendet. Ist 'matchesAll' gesetzt, matcht die DummyBox jede
-// andere Box (sonst nur eine andere DummyBox).
+// A DummyBox is used in pattern matching.
+
+// If `DummyBox::matchesAll' is set, a DummyBox matches any other box
+// (otherwise, only another DummyBox).
 
 
 #include "strclass.h"
@@ -48,15 +49,14 @@
 
 // DummyBox
 
-// Wir leiten eine DummyBox von einer ListBox ab, um mit ihr
-// auch Listen matchen zu koennen.
+// A DummyBox is derived from ListBox, such that we can match Lists.
 
 class DummyBox: public ListBox {
 public:
     DECLARE_TYPE_INFO
 
 protected:
-    // Kopieren
+    // Copy
     DummyBox(const DummyBox& box):
 	ListBox(box)
     {}
@@ -66,14 +66,14 @@ protected:
     bool matches (const Box &b, const Box *callbackArg = 0) const;
 
 public:
-    // Konstruktor
+    // Constructor
     DummyBox(char *t = "DummyBox"):
 	ListBox(t)
     {}
 
     Box *dup() const { return new DummyBox(*this); }
 
-    static bool matchesAll;          // Flag: alles Matchen?
+    static bool matchesAll;          // Flag: match all?
 
     bool isDummyBox() const { return true; }
 };
