@@ -1,8 +1,8 @@
-// $Id: DummyNode.h,v 1.9 1998/03/25 12:43:05 zeller Exp $
-// Deklaration Klasse DummyNode
+// $Id: DummyNode.h,v 1.11 1999/08/19 11:27:26 andreas Exp $
+// A DummyNode returns a DummyBox
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_DummyNode_h
 #define _DDD_DummyNode_h
@@ -34,8 +34,8 @@
 #endif
 
 
-// Ein DummyNode gibt zur Laufzeit eine DummyBox zurueck.
-// Ein DummyNode matcht alle anderen Knoten, wenn matchesAll == true.
+// A DummyNode returns a DummyBox at run-time.
+// A DummyNode matches all other nodes if `DummyNode::matchesAll' is true.
 
 #include "assert.h"
 #include <iostream.h>
@@ -66,12 +66,12 @@ protected:
     }
 
 public:
-    // DummyNode erzeugen
-    DummyNode(char *type = "DummyNode"): 
-	VSLNode(type)
+    // Constructor
+    DummyNode(char *type = "DummyNode")
+	: VSLNode(type)
     {}
 
-    // DummyNode kopieren
+    // Copy
     VSLNode *dup() const
     {
 	return new DummyNode(*this);
