@@ -1,8 +1,8 @@
-// $Id: EntryType.h,v 1.7 1998/06/09 15:55:18 zeller Exp $ -*- C++ -*-
+// $Id: EntryType.h,v 1.9 1999/12/20 12:01:45 andreas Exp $ -*- C++ -*-
 // Entry types in `Settings' panel
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_EntryType_h
 #define _DDD_EntryType_h
@@ -47,7 +47,10 @@ enum EntryType
     CheckOptionMenuEntry,       // Create `check' option menu
     OtherOptionMenuEntry,       // Create other option menu
     TextFieldEntry,		// Create text field
-    SignalEntry		        // Create signal handler
+    SignalEntry,		// Create signal handler
+    ForkOptionMenuEntry,	// Create `follow-fork-mode' option menu
+    DisassemblyOptionMenuEntry,	// Create `disassembly-flavor' option menu
+    SchedulerOptionMenuEntry	// Create `scheduler-locking' option menu
 };
 
 typedef VarArray<EntryType> EntryTypeArray;
