@@ -1,8 +1,8 @@
-// $Id: GraphEditP.h,v 1.18 1998/05/04 17:24:48 zeller Exp $
+// $Id: GraphEditP.h,v 1.23 1999/08/19 11:27:31 andreas Exp $
 // GraphEdit Widget -- private interface
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_GraphEditP_h
 #define _DDD_GraphEditP_h
@@ -83,6 +83,7 @@ typedef struct _GraphEditPart {
     Dimension moveDelta;	// Start move after movement greater than this
     Boolean rubberEdges;	// Draw edges  when moving
     Boolean rubberArrows;	// Draw arrows when moving
+    Boolean rubberAnnotations;	// Draw annotations when moving
     Boolean opaqueMove;		// Draw nodes  when moving
 
     // Selection stuff
@@ -91,6 +92,9 @@ typedef struct _GraphEditPart {
     // Hint stuff
     Boolean showHints;		// Display hints?
 
+    // Annotation stuff
+    Boolean showAnnotations;	// Display annotations?
+
     // Grid stuff
     Boolean showGrid;		// Display grid?
     Dimension gridWidth;	// Grid width (> 0)
@@ -126,6 +130,7 @@ typedef struct _GraphEditPart {
     LayoutMode layoutMode;	         // How to layout graphs
     SelfEdgePosition  selfEdgePosition;  // Position of self-pointing edges
     SelfEdgeDirection selfEdgeDirection; // Its direction
+    Boolean dashedLines;		 // Whether dashed lines are to be used
 
     // Cursors
     Cursor defaultCursor;	         // Standard cursor to use
@@ -144,6 +149,10 @@ typedef struct _GraphEditPart {
     Pixel gridColor;		          // Color to use for grid
     Pixel selectColor;	                  // Color to use for selected nodes
 
+    // Printing colors
+    String nodePrintColor;	          // Color for printing nodes
+    String edgePrintColor;	          // Color for printing edges
+
     // Callbacks
     XtCallbackList positionChangedProc;   // Position changed
     XtCallbackList selectionChangedProc;  // Selection changed
