@@ -1,4 +1,4 @@
-// $Id: ListNode.h,v 1.14 1999/08/19 11:27:40 andreas Exp $
+// $Id: ListNode.h,v 1.15 2000/02/16 11:32:29 andreas Exp $
 // ListNode class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -75,8 +75,10 @@ public:
     // Destructor (including args)
     ~ListNode()
     {
-	if (_head) delete _head;
-	if (_tail) delete _tail;
+	if (_head != 0)
+	    delete _head;
+	if (_tail != 0)
+	    delete _tail;
     }
 
     // Resources
