@@ -1,8 +1,8 @@
-// $Id: MString.h,v 1.21 1998/03/25 12:43:38 zeller Exp $
+// $Id: MString.h,v 1.25 1999/08/19 11:27:40 andreas Exp $
 // Simple interface to Motif composite strings
 
-// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Copyright (C) 1995-1998 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_MString_h
 #define _DDD_MString_h
@@ -52,37 +52,38 @@ private:
 
 public:
     // Constructors
-    MString(char *text = "", 
+    MString(char *text = "",
 	    XmStringCharSet charset = MSTRING_DEFAULT_CHARSET):
-	_mstring(XmStringCreateLtoR(text, charset))
+	_mstring(text ? XmStringCreateLtoR(text, charset) : 0)
     {
 	assert(OK());
     }
 
     MString(const char *text,
 	    XmStringCharSet charset = MSTRING_DEFAULT_CHARSET):
-	_mstring(XmStringCreateLtoR((char *)text, charset))
+	_mstring(text ? XmStringCreateLtoR((char *)text, charset) : 0)
     {
 	assert(OK());
     }
 
-    MString(const string& text, 
+    MString(const string& text,
 	    XmStringCharSet charset = MSTRING_DEFAULT_CHARSET):
 	_mstring(XmStringCreateLtoR((char *)text, charset))
     {
 	assert(OK());
     }
 
-    // In Motif 1.1, `XmString' is defined as `char *'; hence the DUMMY parameter
+    // In Motif 1.1, `XmString' is defined as `char *'; hence the
+    // DUMMY parameter
     MString(XmString text, bool /* dummy */):
-	_mstring(XmStringCopy(text))
+	_mstring(text ? XmStringCopy(text) : 0)
     {
 	assert(OK());
     }
 
     // Copy constructor
     MString(const MString& m):
-	_mstring(XmStringCopy(m._mstring))
+	_mstring(m._mstring ? XmStringCopy(m._mstring) : 0)
     {
 	assert(m.OK());
 	assert(OK());
@@ -106,6 +107,11 @@ public:
 	return XmStringEmpty(_mstring);
     }
 
+    Boolean isNull() const
+    {
+	return xmstring() == 0;
+    }
+
     int lineCount() const
     {
 	return XmStringLineCount(_mstring);
@@ -131,21 +137,11 @@ public:
 	return XmStringLength(_mstring);
     }
 
-    string str(XmStringCharSet charset = MSTRING_DEFAULT_CHARSET) const
-    {
-	char *text;
-	if (XmStringGetLtoR(_mstring, charset, &text))
-	{
-	    string s = text;
-	    XtFree(text);
-	    return s;
-	}
-
-	return "";
-    }
+    // Return all characters, regardless of charset
+    string str() const;
 
     // Assignment
-    MString& operator=(const MString& m)
+    MString& operator = (const MString& m)
     {
 	assert(OK());
 	assert(m.OK());
@@ -164,17 +160,24 @@ public:
 	assert(OK());
 	assert(m.OK());
 
+	if (isNull())
+	    return operator = (m);
+
 	XmString old = _mstring;
 	_mstring = XmStringConcat(_mstring, m._mstring);
 	XmStringFree(old);
 
 	return *this;
     }
+
     MString& prepend(const MString& m)
     {
 	assert(OK());
 	assert(m.OK());
 
+	if (isNull())
+	    return operator = (m);
+
 	XmString old = _mstring;
 	_mstring = XmStringConcat(m._mstring, _mstring);
 	XmStringFree(old);
@@ -202,11 +205,6 @@ public:
     operator XmString()       { return _mstring; }
     XmString xmstring() const { return _mstring; }
 
-    Boolean isNull() const
-    {
-	return xmstring() == 0;
-    }
-
     // Substrings
     Boolean contains(const MString& m) const
     {
@@ -226,6 +224,11 @@ inline MString operator + (const MString& m1, const MString& m2)
     assert(m1.OK());
     assert(m2.OK());
 
+    if (m1.isNull())
+	return m2;
+    if (m2.isNull())
+	return m1;
+
     return MString(XmStringConcat(m1.xmstring(), m2.xmstring()), true);
 }
 
