@@ -1,8 +1,8 @@
-// $Id: PlotAgent.h,v 1.14 1998/11/15 18:24:50 zeller Exp $ -*- C++ -*-
+// $Id: PlotAgent.h,v 1.16 1999/08/19 11:27:46 andreas Exp $ -*- C++ -*-
 // Gnuplot interface
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_PlotAgent_h
 #define _DDD_PlotAgent_h
@@ -113,7 +113,9 @@ public:
     // Add plot point
     void add_point(const string& v, int dim);
     void add_point(int x, const string& v);
+    void add_point(double x, const string& v);
     void add_point(int x, int y, const string& v);
+    void add_point(double x, double y, const string& v);
 
     // Add a break
     void add_break();
