@@ -1,4 +1,4 @@
-// $Id: PosBuffer.h,v 1.25.4.1 1998/12/06 12:59:20 zeller Exp $
+// $Id: PosBuffer.h,v 1.28 1999/08/19 11:27:47 andreas Exp $
 // Filter position information from GDB output.
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_PosBuffer_h
 #define _DDD_PosBuffer_h
@@ -57,6 +57,7 @@ class PosBuffer {
     bool recompiled;		// Program has been recompiled
 
     string auto_cmd_buffer;	// AutoCommand found
+    string auto_cmd_part;	// Prefix of AutoCommand found
 
 protected:
     void filter_gdb(string& answer);
@@ -83,6 +84,7 @@ public:
 	signaled        = false;
 	recompiled      = false;
 	auto_cmd_buffer = "";
+	auto_cmd_part   = "";
 	check_pc        = true;
 	check_func      = true;
     }
@@ -99,6 +101,7 @@ public:
 	  signaled(false),
 	  recompiled(false),
 	  auto_cmd_buffer(""),
+	  auto_cmd_part(""),
 	  check_pc(true),
           check_func(true)
     {
