@@ -1,8 +1,8 @@
-// $Id: SlopeBox.h,v 1.8 1998/03/25 12:44:16 zeller Exp $
-// Klasse SlopeBox (Deklaration)
+// $Id: SlopeBox.h,v 1.11 1999/08/19 11:27:51 andreas Exp $
+// Slope boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_SlopeBox_h
 #define _DDD_SlopeBox_h
@@ -58,7 +58,7 @@ public:
 };
 
 
-// RiseBox
+// RiseBox (`/')
 
 class RiseBox: public SlopeBox {
 public:
@@ -88,11 +88,11 @@ public:
 
     void _print(ostream& os, 
 		const BoxRegion& region, 
-		const BoxPrintGC& gc) const;
+		const PrintGC& gc) const;
 };
 
 
-// FallBox
+// FallBox (`\')
 
 class FallBox: public SlopeBox {
 public:
@@ -122,7 +122,7 @@ public:
 
     void _print(ostream& os, 
 		const BoxRegion& region, 
-		const BoxPrintGC& gc) const;
+		const PrintGC& gc) const;
 };
 
 #endif
