@@ -1,9 +1,9 @@
-// $Id: SourceView.h,v 1.143.4.2 1999/03/14 15:40:32 zeller Exp $
+// $Id: SourceView.h,v 1.147 1999/08/19 11:27:55 andreas Exp $
 // View the Source.
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
 // Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>
-// and Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// and Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -24,8 +24,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 //-----------------------------------------------------------------------------
 // This class creates the source view window and provides necessary
@@ -116,6 +116,7 @@ class SourceView {
     static void BreakpointCmdCB          (Widget, XtPointer, XtPointer);
 
     static void EditBreakpointPropertiesCB (Widget, XtPointer, XtPointer);
+    static void ApplyBreakpointPropertiesCB(Widget, XtPointer, XtPointer);
     static void SetBreakpointIgnoreCountCB (Widget, XtPointer, XtPointer);
     static void SetBreakpointConditionCB   (Widget, XtPointer, XtPointer);
     static void EnableBreakpointsCB        (Widget, XtPointer, XtPointer);
