@@ -1,8 +1,8 @@
-// $Id: VarArray.h,v 1.10 1998/08/01 13:39:21 zeller Exp $
+// $Id: VarArray.h,v 1.12 1999/08/19 11:28:06 andreas Exp $
 // Variable-sized array
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of the ICE Library.
 // 
@@ -64,7 +64,7 @@ protected:
 
 	int sz = size();
 	for (int i = n; i < sz - 1; i++)
-	    _value(i) = _value(i + 1);
+	    this->_value(i) = this->_value(i + 1);
 
 	_size--;
     }
@@ -76,7 +76,7 @@ protected:
 	int sz = size();
 	while (i < sz)
 	{
-	    if (_value(i) == v)
+	    if (this->_value(i) == v)
 	    {
 		_remove(i);
 		sz = size();
