@@ -1,8 +1,9 @@
-// $Id: acconfig.h.in,v 1.39.4.1 1999/03/16 09:56:56 zeller Exp $ -*- C++ -*-
+// $Id: acconfig.h.in,v 1.43 2000/01/17 14:53:41 andreas Exp $ -*- C++ -*-
 // General configuration file.
 
 // Copyright (C) 1995-1999 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Copyright (C) 2000 Universitaet Passau, Germany.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of the ICE Library.
 // 
@@ -85,6 +86,9 @@
 /* Define if MAXPATHLEN is defined or declared in <sys/param.h>. */
 #undef HAVE_MAXPATHLEN
 
+/* Define if the streampos type is defined or declared in <iostream.h>. */
+#undef HAVE_STREAMPOS
+
 /* Define if you have the XP library (X11R6.3 print server).
    Required by Motif 2.1 and later. */
 #undef HAVE_XP
@@ -166,6 +170,9 @@
    executable. */
 #undef WITH_BUILTIN_APP_DEFAULTS
 
+/* Define if you want readline support in DDD. */
+#undef WITH_READLINE
+
 
 // @BOTTOM@
 
@@ -268,6 +275,9 @@
 /* Define if setbuf is declared in stdio.h. */
 #undef HAVE_SETBUF_DECL
 
+/* Define if setlocale is declared in locale.h. */
+#undef HAVE_SETLOCALE_DECL
+
 /* Define if setpgid is declared in unistd.h. */
 #undef HAVE_SETPGID_DECL
 
