@@ -180,7 +180,7 @@
 "\n"
 "\n"
 "\n"
-"std_version() = \"$Id: std.vsl,v 1.6 1997/10/08 13:19:55 zeller Exp $\";\n"
+"std_version() = \"$Id: std.vsl,v 1.7 1999/08/19 11:30:21 andreas Exp $\";\n"
 "\n"
 "\n"
 "rulethickness() = 1;\n"
@@ -556,7 +556,7 @@
 "\n"
 "\n"
 "\n"
-"std_version() = \"$Id: std.vsl,v 1.6 1997/10/08 13:19:55 zeller Exp $\";\n"
+"std_version() = \"$Id: std.vsl,v 1.7 1999/08/19 11:30:21 andreas Exp $\";\n"
 "\n"
 "\n"
 "rulethickness() = 1;\n"
@@ -754,7 +754,7 @@
 "\n"
 "\n"
 "\n"
-"tab_version() = \"$Id: tab.vsl,v 1.8 1998/03/25 14:21:56 zeller Exp $\";\n"
+"tab_version() = \"$Id: tab.vsl,v 1.9 1999/08/19 11:30:21 andreas Exp $\";\n"
 "\n"
 "\n"
 "\n"
@@ -881,7 +881,7 @@
 "\n"
 "\n"
 "\n"
-"fonts_version() = \"$Id: fonts.vsl,v 1.10 1998/04/24 09:38:02 zeller Exp $\";\n"
+"fonts_version() = \"$Id: fonts.vsl,v 1.11 1999/08/19 11:30:20 andreas Exp $\";\n"
 "\n"
 "\n"
 "_font(box, font) = font(box, font);\n"
@@ -1042,7 +1042,7 @@
 "\n"
 "\n"
 "\n"
-"colors_version() = \"$Id: colors.vsl,v 1.4 1997/10/08 13:19:52 zeller Exp $\";\n"
+"colors_version() = \"$Id: colors.vsl,v 1.5 1999/08/19 11:30:19 andreas Exp $\";\n"
 "\n"
 "\n"
 "color(box, fg, bg)   = foreground(background(box, bg), fg);\n"
@@ -1170,6 +1170,10 @@
 "struct_color(vcenter(rm(\"{}\") & hfill()));\n"
 "\n"
 "\n"
+"horizontal_unnamed_struct (...) -> horizontal_array(...);\n"
+"vertical_unnamed_struct (...) -> horizontal_array(...);\n"
+"\n"
+"\n"
 "struct_member_name (name) ->\n"
 "struct_color(rm(name));\n"
 "\n"
@@ -1179,6 +1183,10 @@
 "& vcenter(rm(sep)) & rm(value);\n"
 "\n"
 "\n"
+"struct_member (value) ->\n"
+"rm(value);\n"
+"\n"
+"\n"
 "list_value (...) ->\n"
 "list_color(valign(...));\n"
 "\n"
@@ -1191,6 +1199,10 @@
 "list_color(vcenter(rm(\"\") & hfill()));\n"
 "\n"
 "\n"
+"horizontal_unnamed_list (...) -> horizontal_array(...);\n"
+"vertical_unnamed_list (...)  -> horizontal_array(...);\n"
+"\n"
+"\n"
 "list_member_name (name) ->\n"
 "list_color(rm(name));\n"
 "\n"
@@ -1200,6 +1212,10 @@
 "& vcenter(rm(sep)) & rm(value) & hfill();\n"
 "\n"
 "\n"
+"list_member (value) ->\n"
+"rm(value);\n"
+"\n"
+"\n"
 "sequence_value (...) ->\n"
 "simple_color(fixed_hlist(vwhite(), ...) & hfill());\n"
 "\n"
