@@ -1,8 +1,8 @@
-// $Id: file.h,v 1.16 1998/11/24 09:54:43 zeller Exp $ -*- C++ -*-
+// $Id: file.h,v 1.18 2000/01/12 17:38:21 andreas Exp $ -*- C++ -*-
 // DDD file handling
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_file_h
 #define _DDD_file_h
@@ -74,5 +74,8 @@ struct ProgramInfo {
     ~ProgramInfo() {}
 };
 
+// Last opened file
+extern string open_file_reply;
+
 #endif // _DDD_file_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
