@@ -1,8 +1,8 @@
-// $Id: gdbinit.h,v 1.8 1998/10/21 16:22:35 zeller Exp $ -*- C++ -*-
+// $Id: gdbinit.h,v 1.10 1999/11/02 15:25:01 andreas Exp $ -*- C++ -*-
 // GDB initialization
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_gdbinit_h
 #define _DDD_gdbinit_h
@@ -51,7 +51,12 @@ extern DebuggerType guess_debugger_type(int argc, char *argv[], bool& sure);
 extern bool get_debugger_type(const string& debugger_name, DebuggerType& type);
 
 // Return default program for TYPE
-extern char *default_debugger(DebuggerType type);
+extern char *default_debugger(const string& debugger_name, DebuggerType type);
+
+inline char *default_debugger(DebuggerType type)
+{
+    return default_debugger("", type);
+}
 
 #endif // _DDD_gdbinit_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
