@@ -1,8 +1,8 @@
-// $Id: logo.h,v 1.21 1998/10/03 17:22:37 zeller Exp $ -*- C++ -*-
+// $Id: logo.h,v 1.23 1999/12/17 15:44:30 andreas Exp $ -*- C++ -*-
 // DDD logos and logo functions
 
 // Copyright (C) 1996-1998 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_logo_h
 #define _DDD_logo_h
@@ -69,6 +69,7 @@ extern void set_label(Widget w, const MString& new_label,
 #define DDD_ICON           ddd_NAME
 #define BREAK_AT_ICON      "break_at"
 #define CLEAR_AT_ICON      "clear_at"
+#define CLUSTER_ICON       "cluster"
 #define DELETE_ICON        "delete"
 #define DISABLE_ICON       "disable"
 #define DISPREF_ICON       "dispref"
@@ -88,6 +89,7 @@ extern void set_label(Widget w, const MString& new_label,
 #define ROTATE_ICON        "rotate"
 #define SET_ICON           "set"
 #define SHOW_ICON          "show"
+#define UNCLUSTER_ICON     "uncluster"
 #define UNDISPLAY_ICON     "undisplay"
 #define UNWATCH_ICON       "unwatch"
 #define WATCH_ICON         "watch"
