@@ -1,9 +1,9 @@
 #!/usr/local/bin/perl
-# $Id: perltest.pl,v 1.6.4.1 1998/12/15 18:11:03 zeller Exp $
+# $Id: perltest.pl,v 1.9 2000/02/04 11:32:51 andreas Exp $
 # Perl test
 
 # Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
-# Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+# Written by Andreas Zeller <zeller@gnu.org>.
 # 
 # This file is part of DDD.
 # 
@@ -24,8 +24,8 @@
 # 
 # DDD is the data display debugger.
 # For details, see the DDD World-Wide-Web page, 
-# `http://www.cs.tu-bs.de/softech/ddd/',
-# or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+# `http://www.gnu.org/software/ddd/',
+# or send a mail to the DDD developers <ddd@gnu.org>.
 
 $foo = 42;
 
@@ -73,6 +73,22 @@ $g = newprint("Greetings");
 &$g("earthlings");
 
 
+# Weird keys (from Matthew Persico <Matthew.Persico@lazard.com>)
+my %h = ( 'good' => {
+		     'keyIsOk' => 'valueForGoodKey'
+		    },
+	  'bad' => {
+		    '2KeyIsNotOk' => 'valueForBadKey'
+		    }
+	  );
+
+print $h{good}->{keyIsOk}, "\n";
+print $h{good}->{'keyIsOk'}, "\n";
+## Cannot even compile if this is not commented out:
+## print $h{bad}->{2KeyIsNotOk}, "\n";
+print $h{bad}->{'2KeyIsNotOk'}, "\n";
+
+
 # I/O
 print "What's your name? ";
 chop($name = <>);
@@ -83,7 +99,6 @@ print "Hello, $name!\n";
 $fh = *STDOUT;
 
 
-
 sub print_me {
   print @_;
 }
