@@ -1,8 +1,8 @@
-// $Id: regexps.h,v 1.23 1998/10/23 11:47:06 zeller Exp $ -*- C++ -*-
+// $Id: regexps.h,v 1.25 2000/01/12 17:38:21 andreas Exp $ -*- C++ -*-
 // Regular expressions used in DDD
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_regexps_h
 #define _DDD_regexps_h
@@ -78,6 +78,7 @@ extern const regex rxdotdot;
 extern const regex rxdouble;
 extern const regex rxdown_cmd;
 extern const regex rxenable;
+extern const regex rxenter_file_name;
 extern const regex rxeqeq;
 extern const regex rxfile_cmd;
 extern const regex rxfilepath;
