@@ -1,8 +1,8 @@
-// $Id: session.h,v 1.15 1998/05/21 18:32:40 zeller Exp $ -*- C++ -*-
+// $Id: session.h,v 1.20 1999/09/27 06:05:35 andreas Exp $ -*- C++ -*-
 //
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_session_h
 #define _DDD_session_h
@@ -79,6 +79,11 @@ inline string session_tips_file()
     return session_file(DEFAULT_SESSION, "tips");
 }
 
+inline string session_tmp_flag(const string& session)
+{
+    return session_file(session, "tmp");
+}
+
 // Create session directory for SESSION; leave messages in MSG
 void create_session_dir(const string& session, ostream& msg);
 
@@ -89,10 +94,16 @@ struct LockInfo {
     string hostname;		// Name of host on which DDD is running
     string display;		// Display used by DDD
     int pid;			// DDD process ID
+    int uid;			// DDD user ID
+    string username;		// DDD user name
 
     LockInfo()
-	: hostname(), display(), pid(0)
+	: hostname(), display(), pid(0), uid(0), username()
     {}
+
+    // This should avoid link warnings on SGI
+    // as reported by Mike Tosti <tosti@cinesite.com>
+    ~LockInfo() {}
 };
 
 // Lock session.  Return true iff successful.  Otherwise, return
@@ -111,6 +122,15 @@ void set_session(const string& session);
 // Name of session to be restarted with
 string restart_session();
 
+// True if SESSION is a saved session
+bool is_saved_session(const string& session);
+
+// True if SESSION is temporary
+bool is_temporary_session(const string& session);
+
+// Set temporary flag of SESSION
+void set_tmeporary_session(const string& session, bool temporary);
+
 // Set name of session to be restarted with
 void set_restart_session(const string& session = "");
 
@@ -122,5 +142,8 @@ extern void ShutdownSmSessionCB(Widget, XtPointer, XtPointer);
 extern void OpenSessionCB(Widget, XtPointer, XtPointer);
 extern void SaveSessionAsCB(Widget, XtPointer, XtPointer);
 
+// Restart inferior debugger
+extern void RestartDebuggerCB(Widget, XtPointer, XtPointer);
+
 #endif // _DDD_session_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
