@@ -1,4 +1,4 @@
-// $Id: strclass.h,v 1.32 1999/10/20 11:06:43 andreas Exp $
+// $Id: strclass.h,v 1.33 2000/02/16 11:32:30 andreas Exp $
 // A string class (based on `String' from GNU libg++-2.3)
 
 // This may look like C code, but it is really -*- C++ -*-
@@ -949,7 +949,8 @@ inline void string_DeleteRep(strRep *rep)
 
 inline string::~string()
 {
-    if (rep != &_nilstrRep) string_DeleteRep(rep);
+    if (rep != &_nilstrRep)
+	string_DeleteRep(rep);
 }
 
 inline subString::subString(const subString& x)
@@ -1536,7 +1537,8 @@ inline void string::capitalize()
 inline char&  string::operator [] (unsigned int i) 
 {
 #ifndef NDEBUG
-    if (i >= length()) error("invalid index");
+    if (i >= length())
+	error("invalid index");
 #endif
     return rep->s[i];
 }
@@ -1544,7 +1546,8 @@ inline char&  string::operator [] (unsigned int i)
 inline char string::operator [] (unsigned int i) const
 { 
 #ifndef NDEBUG
-    if (i >= length()) error("invalid index");
+    if (i >= length())
+	error("invalid index");
 #endif
     return rep->s[i];
 }
@@ -1612,7 +1615,8 @@ inline char string::operator [] (unsigned long i) const
 inline char string::elem (int i) const
 { 
 #ifndef NDEBUG
-    if (((unsigned)i) >= length()) error("invalid index");
+    if (((unsigned)i) >= length())
+	error("invalid index");
 #endif
     return rep->s[i];
 }
