@@ -1,4 +1,4 @@
-// $Id: value-read.h,v 1.24 1999/08/19 11:29:01 andreas Exp $
+// $Id: value-read.h,v 1.25 2000/02/11 20:41:10 andreas Exp $
 // Read variable values in string representation
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -78,7 +78,7 @@ void munch_dump_line (string& value);
 string read_vtable_entries (string& value);
 
 // Read struct or class member name; return "" iff error
-string read_member_name (string& value);
+string read_member_name (string& value, bool picky = true);
 
 // Return true if NAME has the form `<FOO>' or `<>'
 bool is_BaseClass_name (const string& name);
